# RCSid:
#	$Id: Makefile.inc,v 1.53 2000/04/03 15:12:42 sjg Exp $
#
#	@(#) Copyright (c) 1995 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@quick.com.au
#

.ifndef _top_inc_
_top_inc_=yes

.if (defined(NLSOWN) && defined(LIBDIR) && ${LIBDIR} == /usr/lib)
# FreeBSD's sys.mk includes bsd.own.mk, undo the damage
.undef LIBDIR
.undef MANDIR
.undef BINMODE
.undef LIBMODE
.endif

# this needs latest bmake
.if !defined(BASE)
.if defined(.PARSEDIR)
BASE!=cd ${.PARSEDIR}; pwd
RELBASE:=${.PARSEDIR:S,^${.CURDIR},,}
.else
.error ${MAKE} cannot set BASE automagically.
.endif
.endif
# this lets them override things
.-include "Makefile.local.inc"

prefix?=/usr/local
SRCDIR?=${BASE}
SJGSRC?=${BASE}
BASEDIR?=${BASE}
INCDIR?=${SRCDIR}/include
BUILDDIR?=build


SBINDIR?=${prefix}/sbin
LIBDIR?=${prefix}/lib
LIBEXECDIR?=${prefix}/libexec
MANDIR?=${prefix}/man
ETCDIR?=${prefix}/etc

.if !(make(*install) || make(install-*))
# while building we install libs into ${LIBDESTDIR}${LIBDIR}
.if defined(MAKEOBJDIRPREFIX)
LIBDESTDIR=${MAKEOBJDIRPREFIX}${BASE}/${BUILDDIR}
.if exists(${MAKEOBJDIRPREFIX}${BASE}/Makefile.local.inc)
.include "${MAKEOBJDIRPREFIX}${BASE}/Makefile.local.inc"
.endif
.elif exists(${BASE}/${BUILDDIR}/${.OBJDIR:T})
LIBDESTDIR=${BASE}/${BUILDDIR}/${.OBJDIR:T}
.else
LIBDESTDIR=${BASE}/${BUILDDIR}
.endif
.ifdef LIB
DESTDIR:=${LIBDESTDIR}
.endif
.endif

.ifdef NOARCHIVE
# on non-dev systems we skip building the archive libs.
# lib${LIB}_pic.a gets updated whenever the .so.* does
# and is easier to track.
DLIBEXT?=_pic.a
.endif

BUILDLIBDIR:=${LIBDESTDIR}${LIBDIR}
.if exists(${BUILDLIBDIR})
LDADD+= -L${BUILDLIBDIR}
.endif
LIBMISC?=${BUILDLIBDIR}/libmisc${DLIBEXT}
LIBNETBSD?=${BUILDLIBDIR}/libnetbsd${DLIBEXT}
LIBTCP?=${BUILDLIBDIR}/libtcp${DLIBEXT}
LIBSIG?=${BUILDLIBDIR}/libsig${DLIBEXT}
LIBSJG?=${BUILDLIBDIR}/libsjg${DLIBEXT}
LIBDBUG?=${BUILDLIBDIR}/libdbug${DLIBEXT}
LIBDMALLOC?=${BUILDLIBDIR}/libdmalloc${DLIBEXT}
LIBMALLOC?=${LIBDSETDMALLOC}
LIBSSLFD?=${BUILDLIBDIR}/libsslfd${DLIBEXT}

.if exists(${LIBSSLFD:R}_pic.a) && !exists(${LIBSSLFD:R}.a)
DLIBEXT?=_pic.a
.endif
DLIBEXT?=.a

.if exists(${LIBNETBSD})
NETBSDLIB?= -lnetbsd
.endif
# we usually only build a shared version of libsjg
.if exists(${LIBSJG}) || exists(${LIBSJG:R}_pic.a) || exists(${LIBSJG:R}.so)
SJGLIB?= -lsjg
# would be nice if .if (${LDADD:M-L${LIBSJG:H}} == "") worked
.if (${LIBSJG:H} != ${BUILDLIBDIR})
SJGLIBS?= -L${LIBSJG:H} ${SJGLIB}
.else
SJGLIBS?= ${SJGLIB}
.endif
.else
SJGLIBS?= ${MISCLIB} ${SIGLIB} ${DBUGLIB}
.endif
.if exists(${LIBMISC})
MISCLIB?= -lmisc
.endif
.if exists(${LIBTCP})
TCPLIB?= -ltcp
.endif
.if exists(${LIBSIG})
SIGLIB?= -lsig
.endif
.if exists(${LIBDBUG})
USE_DBUG?=yes
DBUGLIB?= -ldbug
.endif

.if exists(${LIBDMALLOC})
USE_DMALLOC?=yes
DMALLOCLIB?= -ldmalloc
# we want to use dmalloc in all its glory if we can
# as it finds lots of bugs :-)
.if ${USE_DMALLOC} != "no"
CPPFLAGS+= -DHAVE_DMALLOC_H
MALLOCLIB?= ${DMALLOCLIB}
.endif
.endif

# work out our parent dir.
PDIR=${.CURDIR:H:T}
.if (${PDIR} == "sbin") || (${PDIR} == "lib") || (${PDIR} == "libexec") || (${PDIR} == "etc")
BINDIR?=${prefix}/${PDIR}
.endif
.ifdef PROG
.if (${PDIR} == "libexec")
MAN?=${PROG}.8
.else
MAN?=${PROG}.1
.endif
.endif
.ifdef LIB
MAN?=${SRCS:.c=.3}
.endif
BINDIR?=${prefix}/bin
BINOWN?=root
BINGRP?=wheel
LIBOWN?=root
LIBGRP?=wheel
LIBMODE?=644
BINMODE?=755
.if exists(${BASE}/bmake/install-sh)
INSTALL=${BASE}/bmake/install-sh
.else
# hope it is in $PATH
INSTALL?=install.sh
.endif
.if ${BINOWN} == ""
BININSTALL_FLAGS=${COPY} ${STRIP} -m ${BINMODE}
.else
BININSTALL_FLAGS=${COPY} ${STRIP} -o ${BINOWN} -g ${BINGRP} -m ${BINMODE}
.endif
.if ${LIBOWN} == ""
LIBINSTALL_FLAGS=${COPY} -m ${LIBMODE}
.else
LIBINSTALL_FLAGS=${COPY} -o ${LIBOWN} -g ${LIBGRP} -m ${LIBMODE}
.endif
STRIP?=
COPY?=
#.ifndef BSDOBJDIR
# if BSDOBJDIR is defined, we assume they know what they are doing.
# I use:
# BSDOBJDIR=/usr/local/obj
# BSDSRCDIR=/usr/local/src
# and typically make /usr/local/obj -> src/obj.${MACHINE}
# Note that these variables must be set to what /bin/pwd would print
# in those directories.
# This allows us to export the src read-only, and other hosts
# need only make /usr/local/obj a link to somewhere appropriate and do
# say:
# cd /usr/local/src/obj.i386/sjg &&
# 	find . -type d -print | cpio -pdm /usr/local/obj
# to be ready to rock and roll.
#
#OBJMACHINE=yes
#.endif

CFLAGS+= ${DBG} 
CPPFLAGS+= -I. -I${.CURDIR} -I${.CURDIR}/.. -I${INCDIR}

.if !exists(/usr/local/share/bin/cmt2doc.pl)
EXTRACT_MAN=no
.endif

.-include "Makefile.${MACHINE}.inc"

CONFDIR?=${SRCDIR}/conf

.if defined(MAKEOBJDIRPREFIX) && exists(${MAKEOBJDIRPREFIX}${SRCDIR}/conf/Makefile.inc)
CPPFLAGS+= -I${MAKEOBJDIRPREFIX}${SRCDIR}/conf -I${CONFDIR}
.include "${MAKEOBJDIRPREFIX}${SRCDIR}/conf/Makefile.inc"
.elif exists(${CONFDIR}/${.OBJDIR:T}/Makefile.inc)
CPPFLAGS+= -I${CONFDIR}/${.OBJDIR:T} -I${CONFDIR}
.include "${CONFDIR}/${.OBJDIR:T}/Makefile.inc"
.else
.if exists(/usr/include/stdlib.h) || exists(${INCDIR}/stdlib.h)
CPPFLAGS+= -DHAVE_STDLIB_H
.endif
.if exists(/usr/include/snmp.h) || exists(${INCDIR}/snmp.h)
CPPFLAGS+= -DHAVE_SNMP_H
.endif
.endif

DBG?= -g

# lots of systems no longer define unix, but as far as old s/w
# is concerned they still are.
.if exists(/usr/bin/uname)
CPPFLAGS+= -Dunix
.endif

# some standard stuff for building other peoples packages.
.if exists(${.CURDIR}/src)
.PATH: ${.CURDIR}/src
CPPFLAGS+= -I. -I${.CURDIR} -I${.CURDIR}/src
.elif exists(${.CURDIR:H}/dist)
.if exists(${.CURDIR:H}/dist/${.CURDIR:T})
.PATH: ${.CURDIR:H}/dist/${.CURDIR:T}
CPPFLAGS+= -I${.CURDIR:H}/dist/${.CURDIR:T}
.else
.PATH: ${.CURDIR:H}/dist
.endif
CPPFLAGS+= -I${.CURDIR:H}/dist
.elif exists(${.CURDIR:H:H}/dist)
.if exists(${.CURDIR:H:H}/dist/${.CURDIR:T})
.PATH: ${.CURDIR:H:H}/dist/${.CURDIR:T}
CPPFLAGS+= -I${.CURDIR:H:H}/dist/${.CURDIR:T}
.else
.PATH: ${.CURDIR:H:H}/dist
.endif
CPPFLAGS+= -I${.CURDIR:H:H}/dist
.endif


.if defined(USE_FWTK) && (${USE_FWTK} != "no")
# prog wants FWTK if available
FWTKSRC?=${BASE}/fwtk
.if exists(${BUILDLIBDIR}/libfwtk${DLIBEXT})
LIBFWTK?=${BUILDLIBDIR}/libfwtk${DLIBEXT}
.elif exists(${LIBDIR}/libfwtk${DLIBEXT})
LIBFWTK?=${LIBDIR}/libfwtk${DLIBEXT}
.endif

.if exists(${LIBFWTK})
.if (${LIBFWTK:H} != ${BUILDLIBDIR})
LDADD+= -L${LIBFWTK:H} 
.endif
LIBFWSSL?=${LIBFWTK:H}/libfwssl${DLIBEXT}
.if exists(${LIBFWSSL}) && defined(USE_SSL) && (${USE_SSL} != "no")
FWSSLLIB?=-lfwssl
LDADD+= ${FWSSLLIB} 
.if !defined(LIB) || (${LIB} != "fwssl")
DPADD+= ${LIBFWSSL}
.endif
.endif
FWTKLIB?=-lfwtk
CPPFLAGS+= -I${FWTKSRC}/include
LDADD+= ${FWTKLIB}
.if !defined(LIB) || (${LIB} != "fwtk")
DPADD+= ${LIBFWTK}
.endif
.else
CPPFLAGS+= -DNO_FWTK
.endif
.endif

SSLTOP?=/usr/local/ssl
LIBCRYPTO?=${SSLTOP}/lib/libcrypto${DLIBEXT}
.if !exists(${LIBCRYPTO}) && exists(${LIBDIR}/libcrypto${DLIBEXT})
LIBCRYPTO=${LIBDIR}/libcrypto${DLIBEXT}
.endif
.if !exists(${LIBCRYPTO}) && exists(/usr/local/lib/libcrypto${DLIBEXT})
LIBCRYPTO=/usr/local/lib/libcrypto${DLIBEXT}
.endif
LIBSSL?=${LIBCRYPTO:H}/libssl${DLIBEXT}

.if defined(USE_SSL) && (${USE_SSL} != "no")
# prog wants to use SSL
.if exists(${LIBCRYPTO})
CPPFLAGS+= -DUSE_SSL -I${SSLTOP}/include
.if exists(${SSLTOP}/include/openssl)
CPPFLAGS+= -DUSE_OPENSSL -I${SSLTOP}/include/openssl
.endif
.if !exists(${LIBSSLFD})
# use an installed version
LIBSSLFD!= /bin/ls -1t ${LIBDIR}/libsslfd.* | head -1
.endif
.if exists(${LIBSSLFD})
SSLFDLIB?=-lsslfd
.if !empty(SSLFDLIB)
CPPFLAGS+= -DUSE_SSLFD 
.if (${LIBSSLFD:H} != ${BUILDLIBDIR})
LDADD+= -L${LIBSSLFD:H}
.endif
LDADD+= ${SSLFDLIB}
.if !defined(LIB) || (${LIB} != "sslfd")
DPADD+= ${LIBSSLFD}
.endif
.endif
.endif
SSLLIB?=-lssl
CRYPTOLIB?=-lcrypto
SSLLIBS=${SSLLIB} ${CRYPTOLIB}
.if (${LIBCRYPTO:H} != ${BUILDLIBDIR})
LDADD+= -L${LIBCRYPTO:H} 
.endif
LDADD+= ${SSLLIBS} 
DPADD+= ${LIBCRYPTO} ${LIBSSL}
.endif
.endif

.if defined(USE_SKEY) && (${USE_SKEY} != "no")
# prog wants SKEY if available
.if exists(${BUILDLIBDIR}/libskey.a)
LIBSKEY?=${BUILDLIBDIR}/libskey.a
.if exists(${BASE}/lib/skey)
SKEYSRC?=${BASE}/lib/skey
.endif
.elif exists(${LIBDIR}/libskey.a)
LIBSKEY?=${LIBDIR}/libskey.a}
.if exists(${BASE}/lib/skey)
SKEYSRC?=${BASE}/lib/skey
.endif
.else
LIBSKEY?=/usr/lib/libskey.a
.if exists(/usr/src/lib/libskey)
SKEYSRC?=/usr/src/lib/libskey
.endif
.endif
.if exists(${LIBSKEY})
CPPFLAGS+= -DSKEY -DUSE_SKEY
.ifdef SKEYSRC
CPPFLAGS+= -I${SKEYSRC}
.endif
LDADD+= -lskey
.if !defined(LIB) || (${LIB} != "skey")
DPADD+= ${LIBSKEY}
.endif
.endif
.endif

.ifdef USE_CRYPT
.if exists(/usr/lib/libcrypt.a)
LIBCRYPT?=/usr/lib/libcrypt.a
LDADD+= -lcrypt
DPADD+= ${LIBCRYPT}
.endif
.endif

# we normally don't use lex - too slow
.ifdef USE_LEX
.if exists(/usr/lib/libl.a)
LDADD+= -ll
.endif
.endif

.ifdef SUBDIR
# make sure destination exists
beforeinstall:
	test -d ${DESTDIR}${BINDIR} || ${INSTALL} -m 775 -d ${DESTDIR}${BINDIR}
.endif


LDADD+=${LDSTATIC} -L${LIBDIR} ${LIBS} ${SJGLIBS} ${MALLOCLIB} ${SJGLIBS} 

CFLAGS+= ${XDBG}
LIBRESOLV?=/usr/lib/libresolv${DLIBEXT}
.if exists(${LIBRESOLV})
LDADD+= ${RESOLVLIB}
.endif

LDADD+= ${SOCKETLIB}

LIBCOMPAT?=${LIBDIR}/libcompat${DLIBEXT}
.if !exists(${LIBCOMPAT}) && exists(${LIBDIR}/libcompat.a)
LIBCOMPAT=${LIBDIR}/libcompat.a
.endif
.ifndef LIB
.if defined(COMPATLIB) && !empty(COMPATLIB) && exists(${LIBCOMPAT})
LDADD+= ${COMPATLIB}
.if !defined(LIB) || (${LIB} != "compat")
DPADD+= ${LIBCOMPAT}
.endif
.endif
.endif
.endif	# _top_inc_
